@@ -20,7 +20,7 @@ from hurry.filesize import size as hsize
 from sqlalchemy import func
 
 from pyrone.models.config import get as get_config
-from pyrone.models import DBSession, Article, Tag
+from pyrone.models import DBSession, Article, Tag, Comment
 from pyrone.lib import auth, lang
 from pyrone.lib.lang import supported_langs
 
@@ -127,7 +127,16 @@ def form_checkbox(name, title, value, errors, help=None, label=None, label_help=
     html += '<dd>%(cb)s</dd>' % dict(cb=cb)
     return html
 
-def timestamp_to_str(ts):
+def timestamp_to_dt(ts):
+    """
+    Convert UTC seconds to datetime object
+    """
+    tz = get_config('timezone') 
+    tts = datetime.datetime.utcfromtimestamp(ts) # seconds -> time_struct
+    utc_dt = pytz.utc.localize(tts).astimezone(tz) # utc time -> local time
+    return utc_dt
+
+def timestamp_to_str(ts, fmt='%Y-%m-%d %H:%M'):
     """
     Convert UTC seconds to time string in local timezone
     """
@@ -135,7 +144,7 @@ def timestamp_to_str(ts):
     tts = datetime.datetime.utcfromtimestamp(ts) # seconds -> time_struct
     utc_dt = pytz.utc.localize(tts).astimezone(tz) # utc time -> local time
     
-    t_str = utc_dt.strftime('%Y-%m-%d %H:%M') # '%Z%z'
+    t_str = utc_dt.strftime(fmt.encode('utf-8')).decode('utf-8')
     
     return t_str
 
@@ -158,6 +167,13 @@ def span_info(text, escape=True):
 def cond(condition, true_val, false_val):
     return true_val if condition else false_val
 
+def get_setting(request, id, default_value=None):
+    s = request.registry.settings
+    if id in s:
+        return s[id]
+    else:
+        return default_value
+    
 def user_link(user):
     """
     Generate URL for the user, it could be URL pointing to local user account or to 
@@ -241,3 +257,31 @@ def get_public_tags_cloud(force_reload=False):
     
     return _cache['tags_cloud']
 
+def get_pages_widget_links(lang_code, force_reload=False):
+    
+    if 'pages_links' not in _cache or force_reload:
+        pages_links = list()
+        # fetch from settings, parse, fill cache
+        raw = get_config('widget_pages_pages_spec')
+        for line in raw.split('\n'):
+            line = line.strip()
+            if len(line) == 0:
+                continue
+            # take first char - it will be delimiter
+            delim = line[0]
+            components = line[1:].split(delim)
+            if len(components) != 3:
+                continue
+            lang, url, title = components
+            if not url.startswith('http://') and not url.startswith('https://'):
+                continue
+            link = dict(lang=lang, url=url, title=title)
+            pages_links.append(link)
+        _cache['pages_links'] = pages_links
+    
+    return [x for x in _cache['pages_links'] if x['lang']==lang_code]
+
+def get_not_approved_comments_count():
+    dbsession = DBSession()
+    cnt = dbsession.query(func.count(Comment.id)).filter(Comment.is_approved==False).scalar()
+    return cnt
\ No newline at end of file
